<?php
//
// Post Post Type related functions.
//
add_action('admin_init', 'ci_cpt_post_add_metaboxes');
add_action('save_post', 'ci_cpt_post_update_meta');

if( !function_exists('ci_cpt_post_add_metaboxes') ):
function ci_cpt_post_add_metaboxes(){
	add_meta_box( 'ci_rating_score', __( 'Rating', 'ci_theme' ), 'ci_add_cpt_post_rating_meta_box', 'post', 'normal', 'high' );
	add_meta_box( 'ci_slider', __( 'Slider Details', 'ci_theme' ), 'ci_add_cpt_post_meta_box', 'post', 'normal', 'high' );
}
endif;

if( !function_exists('ci_cpt_post_update_meta') ):
function ci_cpt_post_update_meta($post_id){

	if( !ci_can_save_meta('post') ) return;

	update_post_meta( $post_id, 'rating', sanitize_text_field( $_POST['rating'] ) );

	update_post_meta( $post_id, 'slider', ci_sanitize_checkbox( $_POST['slider'] ) );
	update_post_meta( $post_id, 'slider_bg_id', intval( $_POST['slider_bg_id'] ) );
	update_post_meta( $post_id, 'slider_bg_color', ci_sanitize_hex_color( $_POST['slider_bg_color'] ) );
	update_post_meta( $post_id, 'slider_subtitle', sanitize_text_field( $_POST['slider_subtitle'] ) );
	update_post_meta( $post_id, 'slider_button_text', sanitize_text_field( $_POST['slider_button_text'] ) );

}
endif;

if ( ! function_exists( 'ci_add_cpt_post_rating_meta_box' ) ):
function ci_add_cpt_post_rating_meta_box( $object, $box ) {
	ci_prepare_metabox( 'post' );

	?><p><?php _e( "The rating appears on the top right corner of your post's images and is primarily useful in reviews. However, they can be used for other reasons too.", 'ci_theme' ); ?></p><?php
	?><p><?php _e( "For example, when writing reviews you should type a number such as <strong>10</strong> or <strong>7.8</strong> and group them under a category that includes only reviews. When writing a normal blog post however and you want to add emphasis, you could type something like <strong>Featured</strong> or <strong>Hot!</strong>.", 'ci_theme' ); ?></p><?php
	ci_metabox_input( 'rating', __('Rating:', 'ci_theme') );
}
endif;

if( !function_exists('ci_add_cpt_post_meta_box') ):
function ci_add_cpt_post_meta_box( $object, $box ) {
	ci_prepare_metabox('post');

	$slider_bg_id = get_post_meta( $object->ID, 'slider_bg_id', true );

	ci_metabox_checkbox( 'slider', 'on', __( 'Add this post in the front page slider.', 'ci_theme' ) );

	?><p><?php _e( "You can add both slides and posts into the front page's main slider. The appearance order is determined solely by the publication date, i.e. newest item appears first.", 'ci_theme' ); ?></p><?php
	ci_metabox_input( 'slider_subtitle', __( 'Enter the subtitle of your slide, displayed above the title:', 'ci_theme' ) );
	ci_metabox_input( 'slider_button_text', __( 'Enter the text of the "Read More" slide button:', 'ci_theme' ), array( 'default' => __( 'Read More', 'ci_theme' ) ) );

	?>
	<p><?php _e('The slider displays a secondary image as the background for each slide. Set this here and/or select a solid background color.', 'ci_theme'); ?></p>
	<div class="slider_bg_upload">
		<div class="up-preview">
			<?php if ( ! empty( $slider_bg_id ) ): ?>
				<?php
					$image_url = ci_get_image_src( $slider_bg_id, 'ci_featgal_small_thumb' );
					echo sprintf( '<img src="%s" /><a href="#" class="close media-modal-icon" title="%s"></a>',
						$image_url,
						esc_attr( __('Remove image', 'ci_theme') )
					);
				?>
			<?php endif; ?>
		</div>
		<input type="hidden" class="uploaded-id" name="slider_bg_id" value="<?php echo esc_attr($slider_bg_id); ?>" />
		<input type="button" class="button ci-upload" value="<?php echo esc_attr(__('Select Image', 'ci_theme')); ?>" />
	</div>
	<?php
	ci_metabox_input( 'slider_bg_color', __( 'Background Color:', 'ci_theme' ), array( 'input_class' => 'colorpckr widefat' ) );

}
endif;
