<?php
//
// Slider Post Type related functions.
//
add_action( 'init', 'ci_create_cpt_slider' );
add_action( 'admin_init', 'ci_add_cpt_slider_meta' );
add_action( 'save_post', 'ci_update_cpt_slider_meta' );

if( !function_exists('ci_create_cpt_slider') ):
function ci_create_cpt_slider() {
	$labels = array(
		'name'               => _x( 'Slideshow', 'post type general name', 'ci_theme' ),
		'singular_name'      => _x( 'Slide', 'post type singular name', 'ci_theme' ),
		'add_new'            => __( 'New Slide', 'ci_theme' ),
		'add_new_item'       => __( 'Add New Slide', 'ci_theme' ),
		'edit_item'          => __( 'Edit Slide', 'ci_theme' ),
		'new_item'           => __( 'New Slide', 'ci_theme' ),
		'view_item'          => __( 'View Slide', 'ci_theme' ),
		'search_items'       => __( 'Search Slides', 'ci_theme' ),
		'not_found'          => __( 'No Slides found', 'ci_theme' ),
		'not_found_in_trash' => __( 'No Slides found in the trash', 'ci_theme' ),
		'parent_item_colon'  => __( 'Parent Slide:', 'ci_theme' )
	);

	$args = array(
		'labels'          => $labels,
		'singular_label'  => __( 'Slide', 'ci_theme' ),
		'public'          => false,
		'show_ui'         => true,
		'capability_type' => 'post',
		'hierarchical'    => false,
		'has_archive'     => false,
		'rewrite'         => array( 'slug' => _x( 'slider', 'post type slug', 'ci_theme' ) ),
		'menu_position'   => 5,
		'supports'        => array( 'title', 'thumbnail' ),
		'menu_icon'       => 'dashicons-image-flip-horizontal'
	);

	register_post_type( 'cpt_slider' , $args );
}
endif;

if( !function_exists('ci_add_cpt_slider_meta') ):
function ci_add_cpt_slider_meta() {
	add_meta_box( 'ci_cpt_slider_meta', __( 'Slider Details', 'ci_theme' ), 'ci_add_cpt_slider_meta_box', 'cpt_slider', 'normal', 'high' );
}
endif;

if( !function_exists('ci_update_cpt_slider_meta') ):
function ci_update_cpt_slider_meta( $post_id ) {
	if ( !ci_can_save_meta('cpt_slider') ) return;

	// We need this set to on constantly, so that the slider query can pick up both posts/slides based on custom field.
	update_post_meta( $post_id, 'slider', 'on' );
	update_post_meta( $post_id, 'slider_bg_id', intval( $_POST['slider_bg_id'] ) );
	update_post_meta( $post_id, 'slider_bg_color', ci_sanitize_hex_color( $_POST['slider_bg_color'] ) );
	update_post_meta( $post_id, 'slider_url', esc_url_raw( $_POST['slider_url'] ) );
	update_post_meta( $post_id, 'slider_subtitle', sanitize_text_field( $_POST['slider_subtitle'] ) );
	update_post_meta( $post_id, 'slider_button_text', sanitize_text_field( $_POST['slider_button_text'] ) );
}
endif;

if( !function_exists('ci_add_cpt_slider_meta_box') ):
function ci_add_cpt_slider_meta_box( $object, $box ) {
	ci_prepare_metabox('cpt_slider');

	$slider_bg_id = get_post_meta( $object->ID, 'slider_bg_id', true );

	?><p><?php _e( "You can add both slides and posts into the front page's main slider. The appearance order is determined solely by the publication date, i.e. newest item appears first.", 'ci_theme' ); ?></p><?php
	ci_metabox_input( 'slider_subtitle', __( 'Enter the subtitle of your slide, displayed above the title:', 'ci_theme' ) );
	ci_metabox_input( 'slider_url', __( 'Set a URL below to redirect the user when the "Read More" button of this slide gets clicked. Leaving the URL blank, will hide the button.', 'ci_theme' ), array( 'esc_func' => 'esc_url' ) );
	ci_metabox_input( 'slider_button_text', __( 'Enter the text of the "Read More" slide button:', 'ci_theme' ), array( 'default' => __( 'Learn More', 'ci_theme' ) ) );

	?>
	<p><?php _e('The slider displays a secondary image as the background for each slide. Set this here and/or select a solid background color.', 'ci_theme'); ?></p>
	<div class="slider_bg_upload">
		<div class="up-preview">
			<?php if ( ! empty( $slider_bg_id ) ): ?>
				<?php
					$image_url = ci_get_image_src( $slider_bg_id, 'ci_featgal_small_thumb' );
					echo sprintf( '<img src="%s" /><a href="#" class="close media-modal-icon" title="%s"></a>',
						$image_url,
						esc_attr( __('Remove image', 'ci_theme') )
					);
				?>
			<?php endif; ?>
		</div>
		<input type="hidden" class="uploaded-id" name="slider_bg_id" value="<?php echo esc_attr($slider_bg_id); ?>" />
		<input type="button" class="button ci-upload" value="<?php echo esc_attr(__('Select Image', 'ci_theme')); ?>" />
	</div>
	<?php
	ci_metabox_input( 'slider_bg_color', __( 'Background Color:', 'ci_theme' ), array( 'input_class' => 'colorpckr widefat' ) );

}
endif;
