<?php
/*
 * Term Icons related functions
 */
add_action( 'after_switch_theme', 'ci_theme_term_icons_init' );
if ( ! function_exists( 'ci_theme_term_icons_init' ) ):
function ci_theme_term_icons_init() {
	$icons = get_option( CI_DOMAIN . '_term_icons' );
	if ( $icons === false ) {
		$icons = array(
			1 => 'fa-book'
		);
		update_option( CI_DOMAIN . '_term_icons', $icons );
	}
}
endif;

add_action( 'delete_term', 'ci_theme_term_icons_delete' );
if( ! function_exists( 'ci_theme_term_icons_delete' ) ):
function ci_theme_term_icons_delete( $term_id ) {
	$icons = get_option( CI_DOMAIN . '_term_icons' );
	unset( $icons[ $term_id ] );
	update_option( CI_DOMAIN . '_term_icons', $icons );
}
endif;

add_action( 'category_add_form_fields', 'ci_theme_term_icons_add', 10 );
add_action( 'post_tag_add_form_fields', 'ci_theme_term_icons_add', 10 );
if( ! function_exists( 'ci_theme_term_icons_add' ) ):
function ci_theme_term_icons_add( $term ) {
	?>
	<tr class="form-field">
		<th scope="row"><label for="term-icon"><?php _e( 'Icon code', 'ci_theme' ); ?></label></th>
		<td>
			<input name="term-icon" id="term-icon" type="text" value="" size="40"/>
			<p class="description"><?php echo sprintf( __( 'Icon codes can be found <a target="_blank" href="%s">here</a>. Type them exactly as they are shown (with <strong>fa-</strong> in front), e.g. <strong>fa-rocket</strong>.', 'ci_theme' ), 'http://fontawesome.io/icons/' ); ?></p>
		</td>
	</tr>
	<?php
}
endif;

add_action( 'category_edit_form_fields', 'ci_theme_term_icons_edit', 10, 2 );
add_action( 'post_tag_edit_form_fields', 'ci_theme_term_icons_edit', 10, 2 );
if( ! function_exists( 'ci_theme_term_icons_edit' ) ):
function ci_theme_term_icons_edit( $term, $taxonomy ) {
	$icons = get_option( CI_DOMAIN . '_term_icons' );
	$icon  = ! empty( $icons[ $term->term_id ] ) ? $icons[ $term->term_id ] : '';
	?>
	<tr class="form-field">
		<th scope="row"><label for="term-icon"><?php _e( 'Icon code', 'ci_theme' ); ?></label></th>
		<td>
			<input name="term-icon" id="term-icon" type="text" value="<?php echo esc_attr( $icon ); ?>" size="40"/>
			<p class="description"><?php echo sprintf( __( 'Icon codes can be found <a target="_blank" href="%s">here</a>. Type them exactly as they are shown (with <strong>fa-</strong> in front), e.g. <strong>fa-rocket</strong>.', 'ci_theme' ), 'http://fontawesome.io/icons/' ); ?></p>
		</td>
	</tr>
	<?php
}
endif;

add_action( 'create_term', 'ci_theme_term_icons_save' );
add_action( 'edit_term', 'ci_theme_term_icons_save' );
if( ! function_exists( 'ci_theme_term_icons_save' ) ):
function ci_theme_term_icons_save( $term_id ) {
	if ( isset( $_POST['term-icon'] ) ) {
		$icon  = sanitize_key( $_POST['term-icon'] );
		$icons = get_option( CI_DOMAIN . '_term_icons' );
		if ( isset( $icons[ $term_id ] ) && empty( $icon ) ) {
			unset( $icons[ $term_id ] );
		} else {
			$icons[ $term_id ] = $icon;
		}
		update_option( CI_DOMAIN . '_term_icons', $icons );
	}
}
endif;

if( ! function_exists( 'ci_theme_get_term_icon' ) ):
function ci_theme_get_term_icon( $term_id, $return = 'html' ) {
	$icons = get_option( CI_DOMAIN . '_term_icons' );
	if ( ! empty( $icons[ $term_id ] ) ) {
		switch ( $return ) {
			case 'code':
				return $icons[ $term_id ];
			case 'html':
			default:
				return sprintf( '<i class="fa %s"></i>', $icons[ $term_id ] );
				break;
		}
	}

	return '';
}
endif;
