<?php
if( !class_exists('CI_Items_Widget') ):
class CI_Items_Widget extends WP_Widget {

	function __construct() {
		$widget_ops  = array( 'description' => __( 'Displays a hand-picked selection of posts from a selected post type.', 'ci_theme' ) );
		$control_ops = array( /*'width' => 300, 'height' => 400*/ );
		parent::__construct( 'ci-items', $name = __( '-= CI Items =-', 'ci_theme' ), $widget_ops, $control_ops );

		if ( is_admin() === true ) {
			add_action( 'wp_ajax_ci_items_widget_post_type_ajax_get_posts', 'CI_Items_Widget::_ajax_get_posts' );
		}
	}

	function widget($args, $instance) {
		extract($args);

		$title = apply_filters( 'widget_title', empty( $instance['title'] ) ? '' : $instance['title'], $instance, $this->id_base );

		$types   = $instance['post_types'];
		$ids     = $instance['postids'];
		$columns = $instance['columns'];
		$count   = max( count( $types ), count( $ids ) );


		if ( empty($types) or empty($ids) )
			return;

		$item_classes = '';
		switch( $columns ) {
			case 2:
				$item_classes = 'col-sm-6';
				break;
			case 3:
				$item_classes = 'col-md-4';
				break;
			case 4:
				$item_classes = 'col-sm-6 col-md-3';
				break;
			default:
				$item_classes = 'col-md-4';
				break;
		}

		echo $before_widget;

		if ( $title ) {
			echo $before_title . $title . $after_title;
		}

		if ( in_array( $id, array( 'frontpage-widgets' ) ) ) {
			?><div class="row item-grid"><?php
		} else {
			$item_classes = '';
		}

		for ( $i = 0; $i < $count; $i++ ) {
			$pid       = $ids[ $i ];
			$post_type = $types[ $i ];

			$q = new WP_Query( array(
				'post_type' => $post_type,
				'p'         => $pid
			) );

			while( $q->have_posts() ): $q->the_post();
				$rating = get_post_meta( get_the_ID(), 'rating', true );
				?>
				<div class="<?php echo $item_classes; ?>">
					<div class="item">
						<?php if( has_post_thumbnail() ): ?>
							<figure class="item-thumb">
								<a href="<?php the_permalink(); ?>"><?php the_post_thumbnail(); ?></a>
								<?php if( ! empty( $rating ) ): ?>
									<span class="item-rating"><?php echo $rating; ?></span>
								<?php endif; ?>
							</figure>
						<?php endif; ?>

						<time class="item-time" datetime="<?php echo esc_attr( get_the_date( 'c' ) ); ?>"><?php echo get_the_date(); ?></time>

						<h4 class="item-title"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h4>
						<?php the_excerpt(); ?>
					</div>
				</div>
				<?php
			endwhile;
		}

		wp_reset_postdata();

		if ( in_array( $id, array( 'frontpage-widgets' ) ) ) {
			?></div><!-- /row item-grid --><?php
		}

		echo $after_widget;

	}

	function update($new_instance, $old_instance) {
		$instance = $old_instance;
		$instance['title'] = sanitize_text_field( $new_instance['title'] );

		// Sanitize repeating fields. Remove empty entries.
		$instance['post_types'] = array();
		$instance['postids']    = array();

		$types = $new_instance['post_types'];
		$ids   = $new_instance['postids'];
		$count = max( count( $types ), count( $ids ) );

		for($i = 0; $i < $count; $i++) {
			if ( !empty( $types[ $i ] ) && !empty( $ids[ $i ] ) ) {
				$instance['post_types'][] = sanitize_key( $types[ $i ] );
				$instance['postids'][]    = absint( $ids[ $i ] );
			}
		}

		$instance['columns'] = intval( $new_instance['columns'] );
		return $instance;
	}

	function form($instance) {

		$instance = wp_parse_args( (array) $instance, array(
			'title'      => '',
			'post_types' => array(),
			'postids'    => array(),
			'columns'    => 2,
		) );

		$title      = $instance['title'];
		$post_types = $instance['post_types'];
		$postids    = $instance['postids'];
		$columns    = $instance['columns'];

		?><p><label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title (optional):', 'ci_theme'); ?></label><input id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo esc_attr($title); ?>" class="widefat" /></p><?php

		$post_types_available = get_post_types( array('public' => true), 'objects' );
		unset($post_types_available['attachment']);

		$posttypes_name = $this->get_field_name('post_types') . '[]';
		$ids_name = $this->get_field_name('postids') . '[]';

		?>
		<p><?php _e('Add as many items as you want by pressing the "Add Field" button. Remove any item by selecting "Remove me".', 'ci_theme'); ?></p>
		<fieldset class="ci-repeating-fields ci-items">
			<div class="inside">
				<?php
					if ( ! empty( $postids ) && ! empty( $post_types ) ) {
						$count = max( count( $postids ), count( $post_types ) );
						for( $i = 0; $i < $count; $i++ ) {
							?>
							<div class="post-field">
								<label class="post-field-type"><?php _e( 'Post type:', 'ci_theme' ); ?>
									<select name="<?php echo $posttypes_name; ?>" class="widefat posttype_dropdown">
										<?php
											foreach( $post_types_available as $key => $pt ) {
												?><option value="<?php echo esc_attr($key); ?>" <?php selected($key, $post_types[ $i ]); ?>><?php echo $pt->labels->name; ?></option><?php
											}
										?>
									</select>
								</label>
								<label class="post-field-item"><?php _e( 'Item:', 'ci_theme' ); ?>
									<?php
										wp_dropdown_posts( array(
											'post_type'        => $post_types[ $i ],
											'selected'         => $postids[ $i ],
											'class'            => 'widefat posts_dropdown',
											'show_option_none' => '&nbsp;',
											'select_even_if_empty' => true,
										), $ids_name );
									?>
								</label>
								<p class="ci-repeating-remove-action"><a href="#" class="button ci-repeating-remove-field"><i class="dashicons dashicons-dismiss"></i><?php _e( 'Remove me', 'ci_theme' ); ?></a></p>
							</div>
							<?php
						}
					}
				?>
				<?php
				//
				// Add an empty and hidden set for jQuery
				//
				?>
				<div class="post-field field-prototype" style="display: none;">
					<label class="post-field-type"><?php _e( 'Post type:', 'ci_theme' ); ?>
						<select name="<?php echo $posttypes_name; ?>" class="widefat posttype_dropdown">
							<?php
								foreach( $post_types_available as $key => $pt ) {
									?><option value="<?php echo esc_attr($key); ?>"><?php echo $pt->labels->name; ?></option><?php
								}
							?>
						</select>
					</label>
					<label class="post-field-item"><?php _e( 'Item:', 'ci_theme' ); ?>
						<?php
							wp_dropdown_posts( array(
								'post_type'            => 'post',
								'class'                => 'widefat posts_dropdown',
								'show_option_none'     => '&nbsp;',
								'select_even_if_empty' => true,
							), $ids_name );
						?>
					</label>
					<p class="ci-repeating-remove-action"><a href="#" class="button ci-repeating-remove-field"><i class="dashicons dashicons-dismiss"></i><?php _e( 'Remove me', 'ci_theme' ); ?></a></p>
				</div>
			</div>
			<a href="#" class="ci-repeating-add-field button"><i class="dashicons dashicons-plus-alt"></i><?php _e('Add Field', 'ci_theme'); ?></a>
		</fieldset>

		<p>
			<label for="<?php echo $this->get_field_id('columns'); ?>"><?php _e('Output Columns:', 'ci_theme'); ?></label>
			<select id="<?php echo $this->get_field_id('columns'); ?>" name="<?php echo $this->get_field_name('columns'); ?>">
				<option value="2" <?php selected(2, $columns); ?>>2</option>
				<option value="3" <?php selected(3, $columns); ?>>3</option>
				<option value="4" <?php selected(4, $columns); ?>>4</option>
			</select>
		</p>

		<?php
	}

	static function _ajax_get_posts() {
		$post_type_name = sanitize_key( $_POST['post_type_name'] );
		$name_field     = esc_attr( $_POST['name_field'] );

		$str = wp_dropdown_posts( array(
			'echo'                 => false,
			'post_type'            => $post_type_name,
			'class'                => 'widefat posts_dropdown',
			'show_option_none'     => '&nbsp;',
			'select_even_if_empty' => true,
		), $name_field );

		echo $str;
		die;
	}

} // class


register_widget('CI_Items_Widget');

endif; // !class_exists
?>